@@ -14,6 +14,7 @@ _LOGGER = logging.getLogger(__name__)
 
 DEVICE_MAP = {
     "rockrobo-vacuum-v1": Vacuum,
+    "roborock-vacuum-s5": Vacuum,
     "chuangmi-plug-m1": Plug,
     "chuangmi-plug-v2": Plug,
     "chuangmi-plug-v1": PlugV1,
@@ -31,7 +32,7 @@ DEVICE_MAP = {
     "yunmi-waterpuri-v2": WaterPurifier,
     # It looks like philips devices cannot be discovered via mdns
     "philips-light-bulb": PhilipsBulb,
-    "philips-light-ceil": Ceil,
+    "philips-light-ceiling": Ceil,
     "philips-light-sread1": PhilipsEyecare,
     "xiaomi-wifispeaker-v1": WifiSpeaker,  # name needs to be checked
     "yeelink-light-": Yeelight,
@@ -66,10 +67,13 @@ def create_device(addr, device_cls) -> Device:
 
 
 class Listener:
+    """mDNS listener creating Device objects based on detected devices."""
     def __init__(self):
         self.found_devices = {}  # type: Dict[str, Device]
 
     def check_and_create_device(self, info, addr) -> Optional[Device]:
+        """Create a corresponding :class:`Device` implementation
+         for a given info and address.."""
         name = info.name
         for identifier, v in DEVICE_MAP.items():
             if name.startswith(identifier):
@@ -96,6 +100,10 @@ class Listener:
 
 
 class Discovery:
+    """mDNS discoverer for miIO based devices (_miio._udp.local).
+    Calling :func:`discover_mdns` will cause this to subscribe for updates
+    on ``_miio._udp.local`` until any key is pressed, after which a dict
+    of detected devices is returned."""
     @staticmethod
     def discover_mdns() -> Dict[str, Device]:
         """Discover devices with mdns until """
