@@ -21,6 +21,14 @@ class TimerState(enum.Enum):
     On = "on"
     Off = "off"
 
+
+class Consumable(enum.Enum):
+    MainBrush = "main_brush_work_time"
+    SideBrush = "side_brush_work_time"
+    Filter = "filter_work_time"
+    SensorDirty = "sensor_dirty_time"
+
+
 class Vacuum(Device):
     """Main class representing the vacuum."""
 
@@ -79,10 +87,10 @@ class Vacuum(Device):
     def manual_control(self, rotation: int, velocity: float,
                        duration: int=1500):
         """Give a command over manual control interface."""
-        if rotation <= -180 or rotation >= 180:
+        if rotation < -180 or rotation > 180:
             raise DeviceException("Given rotation is invalid, should "
-                                  "be ]-3.1,3.1[, was %s" % rotation)
-        if velocity <= -0.3 or velocity >= 0.3:
+                                  "be ]-180, 180[, was %s" % rotation)
+        if velocity < -0.3 or velocity > 0.3:
             raise DeviceException("Given velocity is invalid, should "
                                   "be ]-0.3, 0.3[, was: %s" % velocity)
 
@@ -110,10 +118,9 @@ class Vacuum(Device):
         """Return information about consumables."""
         return ConsumableStatus(self.send("get_consumable")[0])
 
-    def consumable_reset(self):
+    def consumable_reset(self, consumable: Consumable):
         """Reset consumable information."""
-        raise NotImplementedError("unknown parameters")
-        # self.send("reset_consumable", ["unknown"])
+        return self.send("reset_consumable", [consumable.value])
 
     def map(self):
         """Return map token."""
@@ -147,7 +154,11 @@ class Vacuum(Device):
         return timers
 
     def add_timer(self, cron: str, command: str, parameters: str):
-        """Add a timer."""
+        """Add a timer.
+
+        :param cron: schedule in cron format
+        :param command: ignored by the vacuum.
+        :param parameters: ignored by the vacuum."""
         import time
         ts = int(round(time.time() * 1000))
         return self.send("set_timer", [
@@ -155,10 +166,16 @@ class Vacuum(Device):
         ])
 
     def delete_timer(self, timer_id: int):
-        """Delete a timer."""
+        """Delete a timer with given ID.
+
+        :param int timer_id: Timer ID"""
         return self.send("del_timer", [str(timer_id)])
 
     def update_timer(self, timer_id: int, mode: TimerState):
+        """Update a timer with given ID.
+
+        :param int timer_id: Timer ID
+        :param TimerStae mode: either On or Off"""
         if mode != TimerState.On and mode != TimerState.Off:
             raise DeviceException("Only 'On' or 'Off' are  allowed")
         return self.send("upd_timer", [str(timer_id), mode.value])
@@ -171,7 +188,12 @@ class Vacuum(Device):
 
     def set_dnd(self, start_hr: int, start_min: int,
                 end_hr: int, end_min: int):
-        """Set do-not-disturb."""
+        """Set do-not-disturb.
+
+        :param int start_hr: Start hour
+        :param int start_min: Start minute
+        :param int end_hr: End hour
+        :param int end_min: End minute"""
         return self.send("set_dnd_timer",
                          [start_hr, start_min, end_hr, end_min])
 
@@ -180,7 +202,9 @@ class Vacuum(Device):
         return self.send("close_dnd_timer", [""])
 
     def set_fan_speed(self, speed: int):
-        """Set fan speed."""
+        """Set fan speed.
+
+        :param int speed: Fan speed to set"""
         # speed = [38, 60 or 77]
         return self.send("set_custom_mode", [speed])
 
